{% load static simpletags %}
{% if "SIMPLEUI_STATIC_OFFLINE"|get_config %}
    <!-- 开发环境版本，包含了有帮助的命令行警告 -->
{#<script src="https://cdn.jsdelivr.net/npm/vue/dist/vue.js"></script>#}
    <script type="text/javascript" src="{% static '/admin/simpleui-x/js/vue.min.js' %}?_={% get_version %}"></script>
    <script type="text/javascript" src="{% static '/admin/simpleui-x/elementui/index.js' %}?_={% get_version %}"></script>
{% else %}
    <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/vue@2.6.11/dist/vue.min.js"></script>
    <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/element-ui@2.13.2/lib/index.js"></script>
{% endif %}