@import "base";

@primary: #19a97b !important;
@color: white;

@menu-color: #484848;
@menu-background: #ffffff !important;

@menu-color-hover: #484848;
@menu-background-hover: #fff;

@menu-title-color: #484848;
@menu-title-background-color: #fff;

@menu-title-color-hover: #666;
@menu-title-background-color-hover: #f2f3f7;


@navbar-color: #FFF;
@navbar-background: #19a97b;

.menu {
  .el-menu-item {
    color: @menu-color !important;
  }
}

.navbar .el-button:focus, .navbar .el-button:hover {
  color: rgba(#FFF, 0.6) !important;
}
